@@ -88,6 +88,8 @@ binandsrc :: String -> SourcesGenerator
 binandsrc url suite = catMaybes
 	[ Just l
 	, Just $ srcLine l
+	, sul
+	, srcLine <$> sul
 	, bl
 	, srcLine <$> bl
 	]
@@ -96,6 +98,10 @@ binandsrc url suite = catMaybes
 	bl = do
 		bs <- backportSuite suite
 		return $ debLine bs url stdSections
+	-- formerly known as 'volatile'
+	sul = do
+		sus <- stableUpdatesSuite suite
+		return $ debLine sus url stdSections
 
 stdArchiveLines :: Propellor SourcesGenerator
 stdArchiveLines = return . binandsrc =<< getMirror
@@ -241,12 +247,17 @@ installed' params ps = robustly $ check (not <$> isInstalled' ps) go
   where
 	go = runApt (params ++ ["install"] ++ ps)
 
-installedBackport :: [Package] -> Property Debian
-installedBackport ps = withOS desc $ \w o -> case o of
+-- | Install packages from the stable-backports suite.
+--
+-- If installing the backport requires installing versions of a package's
+-- dependencies from stable-backports too, you will need to include those
+-- dependencies in the list of packages passed to this function.
+backportInstalled :: [Package] -> Property Debian
+backportInstalled ps = withOS desc $ \w o -> case o of
 	(Just (System (Debian _ suite) _)) -> case backportSuite suite of
 		Nothing -> unsupportedOS'
 		Just bs -> ensureProperty w $
-			runApt (["install", "-t", bs, "-y"] ++ ps)
+			runApt (["install", "-y"] ++ ((++ '/':bs) <$> ps))
 				`changesFile` dpkgStatus
 	_ -> unsupportedOS'
   where
@@ -447,7 +458,7 @@ trustsKey k = trustsKey' k <!> untrustKey k
 trustsKey' :: AptKey -> Property DebianLike
 trustsKey' k = check (not <$> doesFileExist f) $ property desc $ makeChange $ do
 	withHandle StdinHandle createProcessSuccess
-		(proc "gpg" ["--no-default-keyring", "--keyring", f, "--import", "-"]) $ \h -> do
+		(proc "apt-key" ["--keyring", f, "add", "-"]) $ \h -> do
 			hPutStr h (pubkey k)
 			hClose h
 	nukeFile $ f ++ "~" -- gpg dropping
