@@ -15,6 +15,7 @@ import qualified Propellor.Property.Git as Git
 import qualified Propellor.Property.Cron as Cron
 import qualified Propellor.Property.Service as Service
 import qualified Propellor.Property.User as User
+import qualified Propellor.Property.Group as Group
 import qualified Propellor.Property.Borg as Borg
 import qualified Propellor.Property.Apache as Apache
 import qualified Propellor.Property.Postfix as Postfix
@@ -569,6 +570,13 @@ kiteMailServer = propertyList "kitenet.net mail server" $ props
 		, "smtp_tls_loglevel = 1"
 		, "smtp_use_tls = yes"
 		, "smtp_tls_session_cache_database = sdbm:/etc/postfix/smtp_scache"
+
+		, "# Allow larger attachments, up to 200 mb."
+		, "# (Avoid setting too high; the postfix queue must have"
+		, "# 1.5 times this much space free, or postfix will reject"
+		, "# ALL mail!)"
+		, "message_size_limit = 204800000"
+		, "virtual_mailbox_limit = 20480000"
 		]
 		`onChange` Postfix.dedupMainCf
 		`onChange` Postfix.reloaded
@@ -636,6 +644,7 @@ dkimMilter = Postfix.mainCfFile `File.containsLines`
 	`onChange` Postfix.dedupMainCf
 	`onChange` Postfix.reloaded
 	`requires` dkimInstalled
+	`requires` Postfix.installed
 
 -- This does not configure postfix to use the dkim milter,
 -- nor does it set up domainkey DNS.
@@ -907,18 +916,32 @@ alarmClock oncalendar (User user) command = combineProperties "goodmorning timer
 	& "/etc/systemd/logind.conf" `ConfFile.containsIniSetting`
 		("Login", "LidSwitchIgnoreInhibited", "no")
 
--- My home power monitor.
-homePowerMonitor :: IsContext c => User -> [Host] -> c -> (SshKeyType, Ssh.PubKeyText) -> Property (HasInfo + DebianLike)
-homePowerMonitor user hosts ctx sshkey = propertyList "home power monitor" $ props
+homePower :: IsContext c => User -> [Host] -> c -> (SshKeyType, Ssh.PubKeyText) -> Property (HasInfo + DebianLike)
+homePower user hosts ctx sshkey = propertyList "home power" $ props
 	& Apache.installed
 	& Apt.installed ["python", "python-pymodbus", "rrdtool", "rsync"]
 	& File.ownerGroup "/var/www/html" user (userGroup user)
-	& Git.cloned user "git://git.kitenet.net/joey/homepower" d Nothing
-	& buildpoller
-	& Systemd.enabled servicename
-		`requires` serviceinstalled
-		`onChange` Systemd.started servicename
+	& Git.cloned user "https://git.joeyh.name/git/joey/homepower.git" d Nothing
+	& Git.cloned user "https://git.joeyh.name/git/reactive-banana-automation.git" (d </> "reactive-banana-automation") Nothing
+	& build
+	& Systemd.enabled setupservicename
+		`requires` setupserviceinstalled
+		`onChange` Systemd.started setupservicename
+	& Systemd.enabled watchdogservicename
+		`requires` watchdogserviceinstalled
+		`onChange` Systemd.started watchdogservicename
+	& Systemd.enabled pollerservicename
+		`requires` pollerserviceinstalled
+		`onChange` Systemd.started pollerservicename
+	& Systemd.enabled controllerservicename
+		`requires` controllerserviceinstalled
+		`onChange` Systemd.started controllerservicename
 	& User.hasGroup user (Group "dialout")
+	& Group.exists (Group "gpio") Nothing
+	& User.hasGroup user (Group "gpio")
+	& Apt.installed ["i2c-tools"]
+	& User.hasGroup user (Group "i2c")
+	& "/etc/modules-load.d/homepower.conf" `File.hasContent` ["i2c-dev"]
 	& Cron.niceJob "homepower upload"
 		(Cron.Times "1 * * * *") user d rsynccommand
 		`requires` Ssh.userKeyAt (Just sshkeyfile) user ctx sshkey
@@ -929,30 +952,95 @@ homePowerMonitor user hosts ctx sshkey = propertyList "home power monitor" $ pro
   where
 	d = "/var/www/html/homepower"
 	sshkeyfile = d </> ".ssh/key"
-	buildpoller = userScriptProperty (User "joey")
-		[ "cd " ++ d
-		, "make"
-		]
+	build = check (not <$> doesFileExist (d </> "controller")) $
+		userScriptProperty (User "joey")
+			[ "cd " ++ d </> "reactive-banana-automation"
+			, "cabal install"
+			, "cd " ++ d
+			, "make"
+			]
 		`assume` MadeChange
-		`requires` Apt.installed ["ghc", "make"]
-	servicename = "homepower"
-	servicefile = "/etc/systemd/system/" ++ servicename ++ ".service"
-	serviceinstalled = servicefile `File.hasContent`
+		`requires` Apt.installed
+			[ "ghc", "cabal-install", "make"
+			, "libghc-http-types-dev"
+			, "libghc-stm-dev"
+			, "libghc-aeson-dev"
+			, "libghc-wai-dev"
+			, "libghc-warp-dev"
+			, "libghc-http-client-dev"
+			, "libghc-http-client-tls-dev"
+			, "libghc-reactive-banana-dev"
+			, "libghc-hinotify-dev"
+			]
+	pollerservicename = "homepower"
+	pollerservicefile = "/etc/systemd/system/" ++ pollerservicename ++ ".service"
+	pollerserviceinstalled = pollerservicefile `File.hasContent`
 		[ "[Unit]"
-		, "Description=home power monitor"
+		, "Description=home power poller"
 		, ""
 		, "[Service]"
 		, "ExecStart=" ++ d ++ "/poller"
 		, "WorkingDirectory=" ++ d
 		, "User=joey"
 		, "Group=joey"
+		, "Restart=always"
+		, ""
+		, "[Install]"
+		, "WantedBy=multi-user.target"
+		, "WantedBy=homepower-controller.target"
+		]
+	controllerservicename = "homepower-controller"
+	controllerservicefile = "/etc/systemd/system/" ++ controllerservicename ++ ".service"
+	controllerserviceinstalled = controllerservicefile `File.hasContent`
+		[ "[Unit]"
+		, "Description=home power controller"
+		, ""
+		, "[Service]"
+		, "ExecStart=" ++ d ++ "/controller"
+		, "WorkingDirectory=" ++ d
+		, "User=joey"
+		, "Group=joey"
+		, "Restart=always"
 		, ""
 		, "[Install]"
 		, "WantedBy=multi-user.target"
 		]
+	watchdogservicename = "homepower-watchdog"
+	watchdogservicefile = "/etc/systemd/system/" ++ watchdogservicename ++ ".service"
+	watchdogserviceinstalled = watchdogservicefile `File.hasContent`
+		[ "[Unit]"
+		, "Description=home power watchdog"
+		, ""
+		, "[Service]"
+		, "ExecStart=" ++ d ++ "/watchdog"
+		, "WorkingDirectory=" ++ d
+		, "User=root"
+		, "Group=root"
+		, "Restart=always"
+		, ""
+		, "[Install]"
+		, "WantedBy=multi-user.target"
+		]
+	setupservicename = "homepower-setup"
+	setupservicefile = "/etc/systemd/system/" ++ setupservicename ++ ".service"
+	setupserviceinstalled = setupservicefile `File.hasContent`
+		[ "[Unit]"
+		, "Description=home power monitor setup"
+		, ""
+		, "[Service]"
+		, "ExecStart=" ++ d ++ "/setup"
+		, "WorkingDirectory=" ++ d
+		, "User=root"
+		, "Group=root"
+		, "Type=oneshot"
+		, ""
+		, "[Install]"
+		, "WantedBy=multi-user.target"
+		, "WantedBy=homepower.target"
+		]
 	-- Any changes to the rsync command will need my .authorized_keys
 	-- rsync server command to be updated too.
-	rsynccommand = "rsync -e 'ssh -i" ++ sshkeyfile ++ "' -avz rrds/recent/ joey@kitenet.net:/srv/web/homepower.joeyh.name/rrds/recent/"
+	rsynccommand = "rsync -e 'ssh -i" ++ sshkeyfile ++ "' -avz rrds/ joey@kitenet.net:/srv/web/homepower.joeyh.name/rrds/"
 
 -- My home router, running hostapd and dnsmasq for wlan0,
 -- with eth0 connected to a satellite modem, and a fallback ppp connection.
@@ -983,14 +1071,18 @@ homeRouter = propertyList "home router" $ props
 		, "bogus-priv"
 		, "interface=wlan0"
 		, "domain=kitenet.net"
-		, "dhcp-range=10.1.1.100,10.1.1.150,24h"
+		-- lease time is short because the homepower
+		-- controller wants to know when clients disconnect
+		, "dhcp-range=10.1.1.100,10.1.1.150,10m"
 		, "no-hosts"
 		, "address=/honeybee.kitenet.net/10.1.1.1"
+		, "address=/house.kitenet.net/10.1.1.1"
 		]
 		`onChange` Service.restarted "dnsmasq"
 	& ipmasq "wlan0"
 	& Apt.serviceInstalledRunning "netplug"
-	& Network.dhcp' "eth0"
+	& Network.static' "eth0" (IPv4 "192.168.1.100")
+		(Just (Network.Gateway (IPv4 "192.168.1.1")))
 		-- When satellite is down, fall back to dialup
 		[ ("pre-up", "poff -a || true")
 		, ("post-down", "pon")
@@ -1038,21 +1130,23 @@ ipmasq intif = File.hasContent ifupscript
 
 laptopSoftware :: Property DebianLike
 laptopSoftware = Apt.installed
-	[ "intel-microcode"
+	[ "intel-microcode", "acpi"
 	, "procmeter3", "xfce4", "procmeter3", "unclutter"
 	, "mplayer", "fbreader", "firefox", "chromium"
 	, "libdatetime-event-sunrise-perl", "libtime-duration-perl"
-	, "network-manager", "gtk-redshift", "powertop"
+	, "network-manager", "network-manager-openvpn-gnome", "openvpn"
+	, "gtk-redshift", "powertop"
 	, "gimp", "gthumb", "inkscape", "sozi", "xzgv", "hugin"
 	, "mpc", "mpd", "ncmpc", "sonata", "mpdtoys"
 	, "bsdgames", "nethack-console"
 	, "xmonad", "libghc-xmonad-dev", "libghc-xmonad-contrib-dev"
 	, "ttf-bitstream-vera"
-	, "mairix", "offlineimap", "mutt"
-	, "nmap", "whois", "wireshark", "tcpdump", "iftop"
-	, "udevil", "pmount", "tree", "pv"
+	, "mairix", "offlineimap", "mutt", "slrn"
+	, "mtr", "nmap", "whois", "wireshark", "tcpdump", "iftop"
+	, "pmount", "tree", "pv"
 	, "arbtt", "hledger", "bc"
 	, "apache2", "ikiwiki", "libhighlight-perl"
+	, "avahi-daemon", "avahi-discover"
 	, "pal"
 	, "yeahconsole", "xkbset", "xinput"
 	, "assword", "pumpa"
@@ -1063,6 +1157,7 @@ laptopSoftware = Apt.installed
 	, "w3m", "sm", "weechat"
 	, "borgbackup", "wipe", "smartmontools", "libgfshare-bin"
 	, "units"
+	, "virtualbox", "qemu-kvm"
 	]
 	`requires` baseSoftware
 	`requires` devSoftware
@@ -1078,7 +1173,8 @@ devSoftware = Apt.installed
 	[ "build-essential", "debhelper", "devscripts"
 	, "ghc", "cabal-install", "haskell-stack"
 	, "hothasktags", "hdevtools", "hlint"
-	, "gdb", "dpkg-repack", "lintian"
+	, "gdb", "time"
+	, "dpkg-repack", "lintian"
 	, "pristine-tar", "github-backup"
 	]
 
@@ -1094,13 +1190,13 @@ cubieTruckOneWire =
 		["--debian", "sun7i-a20-cubietruck"]
 		`assume` MadeChange
 	mydts =
-		[ "/* Device tree addition enabling onewire sensors on CubieTruck GPIO pin PG8 */"
+		[ "/* Device tree addition enabling onewire sensors on CubieTruck GPIO pin PC21 */"
 		, "#include <dt-bindings/gpio/gpio.h>"
 		, ""
 		, "/ {"
 		, "\tonewire_device {"
 		, "\t\tcompatible = \"w1-gpio\";"
-		, "\t\tgpios = <&pio 6 8 GPIO_ACTIVE_HIGH>; /* PG8 */"
+		, "\t\tgpios = <&pio 2 21 GPIO_ACTIVE_HIGH>; /* PC21 */"
 		, "\t\tpinctrl-names = \"default\";"
 		, "\t\tpinctrl-0 = <&my_w1_pin>;"
 		, "\t};"
@@ -1108,7 +1204,7 @@ cubieTruckOneWire =
 		, ""
 		, "&pio {"
 		, "\tmy_w1_pin: my_w1_pin@0 {"
-		, "\t\tallwinner,pins = \"PG8\";"
+		, "\t\tallwinner,pins = \"PC21\";"
 		, "\t\tallwinner,function = \"gpio_in\";"
 		, "\t};"
 		, "};"
